@@ -1,10 +1,5 @@
 package Perinci::Sub::Complete;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-07'; # DATE
-our $DIST = 'Perinci-Sub-Complete'; # DIST
-our $VERSION = '0.944'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -13,10 +8,14 @@ use Log::ger;
 use Complete::Common qw(:all);
 use Complete::Sah;
 use Complete::Util qw(hashify_answer complete_array_elem complete_hash_key combine_answers modify_answer);
+use Exporter 'import';
 use Perinci::Sub::Util qw(gen_modified_sub);
 
-require Exporter;
-our @ISA       = qw(Exporter);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-28'; # DATE
+our $DIST = 'Perinci-Sub-Complete'; # DIST
+our $VERSION = '0.945'; # VERSION
+
 our @EXPORT_OK = qw(
                        complete_from_schema
                        complete_arg_val
@@ -1086,7 +1085,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.944 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2021-05-07.
+This document describes version 0.945 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2022-08-28.
 
 =head1 SYNOPSIS
 
@@ -1529,7 +1528,7 @@ the result of this function for bash.
 
 Usage:
 
- complete_from_schema(%args) -> [status, msg, payload, meta]
+ complete_from_schema(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Complete a value from schema.
 
@@ -1558,12 +1557,12 @@ case schema must already be normalized.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1577,14 +1576,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Complete>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Complete>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Complete>, L<Complete::Getopt::Long>
@@ -1595,11 +1586,43 @@ L<Perinci::CmdLine>, L<Perinci::CmdLine::Lite>, L<App::riap>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Complete>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
